import { SocketDtoDirectionEnum, SocketDtoTypeEnum } from '@smallstack/axios-api-client';
import { AllWidgetTags, WidgetTag } from '@smallstack/widget-core';

const CONFIG_LINKED_ID_FILTER$1 = "linkedIdFilter";
const CONFIG_BILLING_PARTY_ID_FILTER = "billingPartyIdFilter";
const AnytimeTodosWidget = {
    name: "AnytimeTodos",
    configuration: {
        templateName: '"Jederzeit" Aufgaben',
        templateDescription: "Zeigt alle Aufgaben an, die jederzeit ausgeführt und nicht an ein Datum gebunden sind.",
        icon: "task",
        dataSchema: {
            type: "object",
            properties: {
                [CONFIG_LINKED_ID_FILTER$1]: {
                    type: "string",
                    title: "Filter nach verlinkter ID",
                    description: "Wenn gesetzt, werden nur Aufgaben angezeigt, die mit dieser ID verlinkt sind."
                },
                [CONFIG_BILLING_PARTY_ID_FILTER]: {
                    type: "string",
                    title: "Filter nach verlinkter Rechnungspartei",
                    description: "Wenn gesetzt, werden nur Aufgaben angezeigt, die mit dieser Rechnungspartei verlinkt sind."
                }
            }
        }
    },
    component: () => import('./smallstack-todo-widgets-anytime-todos-widget.component-798ecc90.mjs').then((m) => m.AnytimeTodosWidgetComponent)
};

const CreateNoteWidget = {
    name: "CreateNote",
    configuration: {
        templateName: "Notiz erstellen",
        templateDescription: "Mit diesem Widget können Notizen erstellt werden.",
        dataSchema: {
            type: "object",
            properties: {
                targetId: {
                    type: "string",
                    title: "Id der Ziel Entität",
                    description: "An welche Entität soll die Notiz gehängt werden?"
                },
                targetType: {
                    type: "string",
                    title: "Typ der Ziel Entität",
                    description: "Geben Sie hier den Datentyp an",
                    "x-schema-form": {
                        widget: "types"
                    }
                }
            }
        },
        icon: "note",
        tags: AllWidgetTags,
        sockets: [{ direction: SocketDtoDirectionEnum.Out, name: "noteCreated", type: SocketDtoTypeEnum.Object }]
    },
    component: () => import('./smallstack-todo-widgets-create-note-widget.component-01c27720.mjs').then((m) => m.CreateNoteWidgetComponent)
};

const SchedulingRuleDisplayWidget = {
    name: "SchedulingRuleDisplay",
    configuration: {
        templateName: "Erstellungsregel",
        templateDescription: "Zeigt eine Erstellungsregel und deren nächste Termine an.",
        icon: "calendar",
        dataSchema: {
            type: "object",
            properties: {
                property: {
                    type: "string",
                    title: "Eigenschaft",
                    description: "Die Eigenschaft, welche die Erstellungsregel (v1) enthält."
                }
            }
        }
    },
    component: () => import('./smallstack-todo-widgets-scheduling-rule-display-widget.component-f147471a.mjs').then((m) => m.SchedulingRuleDisplayWidgetComponent)
};

const CONFIG_ONLY_MINE = "onlyMine";
const CONFIG_LINKED_ID_FILTER = "linkedIdFilter";
const TodoAgendaWidget = {
    name: "TodoAgenda",
    configuration: {
        icon: "task",
        tags: AllWidgetTags,
        templateName: "Aufgaben Agenda",
        templateDescription: "Zeigt eine chronologische Agenda aller Aufgaben an",
        dataSchema: {
            type: "object",
            properties: {
                [CONFIG_ONLY_MINE]: {
                    title: "Zeige nur zugewiesene?",
                    type: "boolean",
                    description: "Falls aktiv, dann werden nur Aufgaben in der Agenda gezeigt, welche dem angemeldeten Benutzer oder niemandem zugewiesen sind."
                },
                [CONFIG_LINKED_ID_FILTER]: {
                    title: "Zeige nur für verknüpftes Objekt?",
                    type: "string",
                    description: "Falls aktiv, dann werden nur Aufgaben in der Agenda gezeigt, welche mit dem verknüpften Objekt verknüpft sind."
                }
            }
        }
    },
    component: () => import('./smallstack-todo-widgets-todo-agenda-widget.component-146a8d10.mjs').then((m) => m.TodoAgendaWidgetComponent)
};

const TodoTemplateOwnerReplacementEditorWidget = {
    name: "TodoTemplateOwnerReplacementEditor",
    configuration: {
        icon: "sorting-arrows-horizontal",
        templateName: "Aufgaben Vorlagen Vertretungseditor",
        templateDescription: "Hier können Sie Vertretungen für Aufgaben Vorlagen definieren.",
        dataSchema: {
            type: "object",
            properties: {}
        },
        sockets: [
            { name: "save", direction: SocketDtoDirectionEnum.In, type: SocketDtoTypeEnum.Undefined },
            { name: "validate", type: SocketDtoTypeEnum.Undefined, direction: SocketDtoDirectionEnum.In }
        ]
    },
    component: () => import('./smallstack-todo-widgets-todo-template-owner-replacement-editor-widget.component-209fbd0d.mjs').then((m) => m.TodoTemplateOwnerReplacementEditorWidgetComponent)
};

const WorklogWidget = {
    name: "Worklogs",
    configuration: {
        icon: "work",
        tags: [WidgetTag.APPLICATION, WidgetTag.CBO, WidgetTag.CMS, WidgetTag.DASHBOARD],
        templateName: "Arbeitsprotokolle",
        templateDescription: "Zeigt alle Arbeitsprotokolle des aktuell angemeldeten Benutzers.",
        dataSchema: {
            type: "object",
            properties: {
                showDeleteBtn: {
                    type: "boolean",
                    title: "Löschen Button anzeigen?"
                },
                showEditBtn: {
                    type: "boolean",
                    title: "Bearbeiten Button anzeigen?"
                }
            }
        }
    },
    component: () => import('./smallstack-todo-widgets-worklog-widget.component-dd437e75.mjs').then((m) => m.WorklogWidgetComponent)
};

function addTodoWidgets(widgetRegistry) {
    widgetRegistry.addWidget(TodoAgendaWidget);
    widgetRegistry.addWidget(CreateNoteWidget);
    widgetRegistry.addWidget(WorklogWidget);
    widgetRegistry.addWidget(AnytimeTodosWidget);
    widgetRegistry.addWidget(SchedulingRuleDisplayWidget);
    widgetRegistry.addWidget(TodoTemplateOwnerReplacementEditorWidget);
}

/**
 * Generated bundle index. Do not edit.
 */

export { CONFIG_LINKED_ID_FILTER$1 as C, CONFIG_BILLING_PARTY_ID_FILTER as a, CONFIG_ONLY_MINE as b, CONFIG_LINKED_ID_FILTER as c, addTodoWidgets as d };
//# sourceMappingURL=smallstack-todo-widgets-smallstack-todo-widgets-9aa96321.mjs.map
